@@ -1,18 +1,17 @@
 package Test::Class::Moose::Role;
-$Test::Class::Moose::Role::VERSION = '0.50';
+$Test::Class::Moose::Role::VERSION = '0.51';
 # ABSTRACT: Test::Class::Moose for roles
 
 use 5.10.0;
 use Carp;
 
+use Sub::Attribute;
 use Test::Class::Moose::AttributeRegistry;
 
 BEGIN {
     require Test::Class::Moose;
-    eval "use Sub::Attribute";
-    unless ( Test::Class::Moose->__attributes_unavailable ) {
-        eval Test::Class::Moose->__create_attributes;
-    }
+    eval Test::Class::Moose->__create_attributes;
+    croak($@) if $@;
 }
 
 sub import {
@@ -23,19 +22,15 @@ sub import {
 package $caller;
 use Moose::Role;
 use Test::Most;
+use Sub::Attribute;
 END
 
-    unless ( Test::Class::Moose->__attributes_unavailable ) {
-        $preamble .= "use Sub::Attribute;\n";
-    }
     eval $preamble;
     croak($@) if $@;
-    unless ( Test::Class::Moose->__attributes_unavailable ) {
-        no strict "refs";
-        *{"$caller\::Tags"}  = \&Tags;
-        *{"$caller\::Test"}  = \&Test;
-        *{"$caller\::Tests"} = \&Tests;
-    }
+    no strict "refs";
+    *{"$caller\::Tags"}  = \&Tags;
+    *{"$caller\::Test"}  = \&Test;
+    *{"$caller\::Tests"} = \&Tests;
 }
 
 1;
@@ -52,7 +47,7 @@ Test::Class::Moose::Role - Test::Class::Moose for roles
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =head1 DESCRIPTION
 
